@@ -22,11 +22,11 @@ DBIx::NinjaORM - Flexible Perl ORM for easy transitions from inline SQL to objec
 
 =head1 VERSION
 
-Version 2.3.2
+Version 2.4.0
 
 =cut
 
-our $VERSION = '2.3.2';
+our $VERSION = '2.4.0';
 
 
 =head1 DESCRIPTION
@@ -2938,7 +2938,21 @@ sub parse_filtering_criteria
 	my $filtering_field_keys_passed = 0;
 	foreach my $field ( sort keys %$filters )
 	{
+		# "field => undef" and "field => []" are not valid filtering
+		# criteria. This prevents programming errors, by forcing the
+		# use of the 'null' operator when you explicitely want to
+		# test for NULL. See:
+		#
+		#     field =>
+		#     {
+		#         operator => 'null',
+		#     }
+		#
 		next unless defined( $filters->{ $field } );
+		next if Data::Validate::Type::is_arrayref( $filters->{ $field } )
+			&& scalar( @{ $filters->{ $field } } ) == 0;
+		
+		# We now have a valid filtering criteria.
 		$filtering_field_keys_passed = 1;
 		
 		# Add the table prefix if needed, this will prevent conflicts if the
